agentle.agents.whatsapp.models.whatsapp\_session
================================================

.. automodule:: agentle.agents.whatsapp.models.whatsapp_session

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      BaseModel
      MutableMapping
      WhatsAppContact
      WhatsAppSession
      datetime
   